=============
Configuration
=============

.. note::

   Currently Jaffle does not check the configuration file syntax. If Jaffle does not work as you expect, please check the configuration carefully. Jaffle will have the configuration validation in the future release.

Syntax
======

.. toctree::
   :maxdepth: 1

   syntax
   interpolation

Configuration Blocks
====================

.. toctree::
   :maxdepth: 1

   kernel
   app
   process
   job
   logger
   variable
